<?php

//------------------------------------------------------------------------
// This script is a part of ABC Mail Manager
//
// Version: 2.5
// Homepage: www.zakkis.ca
// Copyright (c) 2002-2003 Zakkis Technology, Inc.
// All rights reserved.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
// FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
// REGENTS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
// INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
// STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
// OF THE POSSIBILITY OF SUCH DAMAGE.
//
//------------------------------------------------------------------------
	
/**
* Class to host uploading form.
*	Assume that names:
*		- upl_FileXX 	- one of from currently uploaded file.
*					where XX - number = 0 - 3.
*		- upl_DelFileXX - one of uploaded file to delete from upload list.
*					where XX - uploaded file id.
*	is reserved by this form.
*
*/

class UploadForm
{
	var $ext = 'upl';
	var $timeout = 3600;
	
	var $dir;
	var $index_file;
	var $upload_id_name;
	var $upload_id;
	var $data = array();
	var $tm;
	

	function UploadForm( $dir, $id = 'FileUploadID' )
	{
		global $HTTP_POST_VARS, $HTTP_POST_FILES;

		//
		// Setup parameters
		
		$this->dir = $dir;
		$this->upload_id_name = $id;
		
		/*
		print '<pre>';
		print_r($HTTP_POST_VARS);
		print '</pre>';
		*/
		
		if( isset( $HTTP_POST_VARS[ $id ] ) )
			$this->upload_id = $HTTP_POST_VARS[ $id ];
		else
			$this->upload_id = uniqid('');
		
		$this->index_file = $this->dir . '/' . $this->upload_id . '.' . 'dat';
		
		// Try to load currently uploaded information		
		if( file_exists( $this->index_file ) )
		{
			$data = file( $this->index_file );
			if( count( $data ) != 0 )
			{
				$this->tm = $data[ 0 ];
				if( count( $data ) > 1 )
					for( $i = 1; $i < count( $data ); $i++ )
					{
						$line = trim( $data[ $i ] );
						$parts = explode( ":", $line );						
						
						$cur = count( $this->data );
						$this->data[ $cur ][ 'name' ] = $parts[ 0 ];
						$this->data[ $cur ][ 'id' ] = $parts[ 1 ];
						$this->data[ $cur ][ 'file' ] = $this->dir . '/' . $parts[ 1 ] . ".$this->ext";
					}
			}
		}
		
		//
		// Handle passed parameters - assume POST used.
		
		$need_save = false;
		
		for( $i = 0; $i < count($this->data); $i++ )
		{
			$item = $this->data[ $i ];
			$name = 'upl_DelFile_' . $item['id'];
			if( isset( $HTTP_POST_VARS[ $name ] ) )
			{
				$this->data[ $i ]['delete'] = true;
				$need_save = true;
			}
		}
		
		//
		// Handle upload files
		
		foreach( $HTTP_POST_FILES as $attachment )
		{
			$name = $attachment['name'];
			if( $name == "" )
				continue;
				
			$tmpname = $attachment['tmp_name'];
			$id = uniqid('');
			$filename = $this->dir . '/' . $id . ".$this->ext";
			
			if( move_uploaded_file( $tmpname, $filename ) )
			{
				$cur = count( $this->data );
				$this->data[ $cur ][ 'name' ] = $name;
				$this->data[ $cur ][ 'id' ] = $id;
				$this->data[ $cur ][ 'file' ] = $filename;
				
				$need_save = true;
			}
		}
		
		if( $need_save )
			$this->SaveIndex();
			
		$this->CleanOldUploads();
	}
	
	function GetCount()
	{
		return count( $this->data );
	}
	
	function CleanOldUploads()
	{
		$handle = opendir( $this->dir );
		
		while (false !== ($file = readdir($handle)))
		{ 
			$parts = pathinfo( $file );
			if( $parts['extension'] != 'dat' )
				continue;
				
			$filename = $this->dir . '/' . $file;
			if( $filename == $this->index_file )
				continue;
			
			$data = file( $filename );
			if( count( $data ) != 0 )
			{
				$tm = $data[ 0 ];
				if( time() - $tm >= $this->timeout )
				{
					if( count( $data ) > 1 )
						for( $i = 1; $i < count( $data ); $i++ )
						{
							$line = trim( $data[ $i ] );
							$parts = explode( ":", $line );						
							unlink( $this->dir . '/' . $parts[ 1 ] . ".$this->ext" );
						}
						
					unlink( $this->dir . '/' . $file );
				}
			}
		}
		
		closedir($handle); 

	}
	
	function SaveIndex()
	{
		$fd = fopen( $this->index_file, 'wb+' );
		if( !$fd )
			return;
			
		$tm = time();
		$content = "$tm";
			
		foreach( $this->data as $item )
		{
			if( $item['delete'] == true )
				continue;
			
			if( $content != '' )
				$content .= "\n";
			
			$content .= $item['name'] . ':' . $item['id'];
		}
		
		fwrite( $fd, $content );
		fclose( $fd );
		
		//
		// Really delete items marked to delete
		$count = count( $this->data );
		for( $i = 0; $i < $count; $i++ )
			if( $this->data[ $i ]['delete'] == true )
			{
				unlink( $this->data[ $i ][ 'file' ] );
				unset( $this->data[ $i ] );
			}
	}
	
	function PrintAttachedList( $img = '', $print_del = true )
	{
		if( count( $this->data ) == 0 )
			return false;
	
		print "\t\t<table width=\"100%\">\n";
		foreach( $this->data as $item )
		{
			if( $item['delete'] === true )
				continue;
			
			$name0 = $item['name'];
			$name = 'upl_DelFile_' . $item['id'];
			
			print "\t\t\t<tr>\n";
			
			if( $img != '' )
			{
				print <<<END
				<td>
					<img src="$img">
				</td>

END;
			}
			
			print <<<END
				<td width=30%>
					$name0
				</td>

END;
			if( $print_del )
			{	
			print <<<END
				<td>
					<input type=checkbox name = "$name">
					<font color=#ff0000>Delete</font>
				</td>

END;
			}
			
			print "			</tr>\n";
		}
		
		print "\t\t</table>\n";
		
		return true;
	}
	
	function PrintUploadID()
	{
		if( count( $this->data ) == 0 )
			return;
	
		print <<<END
		<input type=hidden name="$this->upload_id_name" value="$this->upload_id">

END;
	}
	
	function PrintInput( $display_name = 'Attachment')
	{
		static $counter = 1;
		print <<<END
		$display_name $counter: <input type=file name="upl_File_$counter"><br>

END;

		$counter++;
	}

} // end of clas UploadForm


?>